@@ -31,7 +31,7 @@ Usage::
     poll_for_decision_task_paginator: PollForDecisionTaskPaginator = client.get_paginator("poll_for_decision_task")
     ```
 """
-from mypy_boto3_swf.client import SWFClient as Client, SWFClient
+from mypy_boto3_swf.client import SWFClient
 from mypy_boto3_swf.paginator import (
     GetWorkflowExecutionHistoryPaginator,
     ListActivityTypesPaginator,
@@ -42,6 +42,8 @@ from mypy_boto3_swf.paginator import (
     PollForDecisionTaskPaginator,
 )
 
+Client = SWFClient
+
 
 __all__ = (
     "Client",
