@@ -1,4 +1,4 @@
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import,unused-argument,super-init-not-called
 """
 Main interface for swf service client
 
@@ -14,8 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.exceptions import ClientError as Boto3ClientError
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.client import ClientMeta
 
 from mypy_boto3_swf.paginator import (
     GetWorkflowExecutionHistoryPaginator,
@@ -65,30 +64,39 @@ else:
 __all__ = ("SWFClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    DefaultUndefinedFault: Type[Boto3ClientError]
-    DomainAlreadyExistsFault: Type[Boto3ClientError]
-    DomainDeprecatedFault: Type[Boto3ClientError]
-    LimitExceededFault: Type[Boto3ClientError]
-    OperationNotPermittedFault: Type[Boto3ClientError]
-    TooManyTagsFault: Type[Boto3ClientError]
-    TypeAlreadyExistsFault: Type[Boto3ClientError]
-    TypeDeprecatedFault: Type[Boto3ClientError]
-    UnknownResourceFault: Type[Boto3ClientError]
-    WorkflowExecutionAlreadyStartedFault: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    DefaultUndefinedFault: Type[BotocoreClientError]
+    DomainAlreadyExistsFault: Type[BotocoreClientError]
+    DomainDeprecatedFault: Type[BotocoreClientError]
+    LimitExceededFault: Type[BotocoreClientError]
+    OperationNotPermittedFault: Type[BotocoreClientError]
+    TooManyTagsFault: Type[BotocoreClientError]
+    TypeAlreadyExistsFault: Type[BotocoreClientError]
+    TypeDeprecatedFault: Type[BotocoreClientError]
+    UnknownResourceFault: Type[BotocoreClientError]
+    WorkflowExecutionAlreadyStartedFault: Type[BotocoreClientError]
 
 
 class SWFClient:
     """
-    [SWF.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client)
+    [SWF.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.can_paginate)
         """
 
     def count_closed_workflow_executions(
@@ -102,7 +110,7 @@ class SWFClient:
         closeStatusFilter: CloseStatusFilterTypeDef = None,
     ) -> WorkflowExecutionCountTypeDef:
         """
-        [Client.count_closed_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.count_closed_workflow_executions)
+        [Client.count_closed_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.count_closed_workflow_executions)
         """
 
     def count_open_workflow_executions(
@@ -114,62 +122,62 @@ class SWFClient:
         executionFilter: WorkflowExecutionFilterTypeDef = None,
     ) -> WorkflowExecutionCountTypeDef:
         """
-        [Client.count_open_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.count_open_workflow_executions)
+        [Client.count_open_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.count_open_workflow_executions)
         """
 
     def count_pending_activity_tasks(
         self, domain: str, taskList: "TaskListTypeDef"
     ) -> PendingTaskCountTypeDef:
         """
-        [Client.count_pending_activity_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.count_pending_activity_tasks)
+        [Client.count_pending_activity_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.count_pending_activity_tasks)
         """
 
     def count_pending_decision_tasks(
         self, domain: str, taskList: "TaskListTypeDef"
     ) -> PendingTaskCountTypeDef:
         """
-        [Client.count_pending_decision_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.count_pending_decision_tasks)
+        [Client.count_pending_decision_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.count_pending_decision_tasks)
         """
 
     def deprecate_activity_type(self, domain: str, activityType: "ActivityTypeTypeDef") -> None:
         """
-        [Client.deprecate_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.deprecate_activity_type)
+        [Client.deprecate_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.deprecate_activity_type)
         """
 
     def deprecate_domain(self, name: str) -> None:
         """
-        [Client.deprecate_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.deprecate_domain)
+        [Client.deprecate_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.deprecate_domain)
         """
 
     def deprecate_workflow_type(self, domain: str, workflowType: "WorkflowTypeTypeDef") -> None:
         """
-        [Client.deprecate_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.deprecate_workflow_type)
+        [Client.deprecate_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.deprecate_workflow_type)
         """
 
     def describe_activity_type(
         self, domain: str, activityType: "ActivityTypeTypeDef"
     ) -> ActivityTypeDetailTypeDef:
         """
-        [Client.describe_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.describe_activity_type)
+        [Client.describe_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.describe_activity_type)
         """
 
     def describe_domain(self, name: str) -> DomainDetailTypeDef:
         """
-        [Client.describe_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.describe_domain)
+        [Client.describe_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.describe_domain)
         """
 
     def describe_workflow_execution(
         self, domain: str, execution: "WorkflowExecutionTypeDef"
     ) -> WorkflowExecutionDetailTypeDef:
         """
-        [Client.describe_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.describe_workflow_execution)
+        [Client.describe_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.describe_workflow_execution)
         """
 
     def describe_workflow_type(
         self, domain: str, workflowType: "WorkflowTypeTypeDef"
     ) -> WorkflowTypeDetailTypeDef:
         """
-        [Client.describe_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.describe_workflow_type)
+        [Client.describe_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.describe_workflow_type)
         """
 
     def generate_presigned_url(
@@ -180,7 +188,7 @@ class SWFClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.generate_presigned_url)
         """
 
     def get_workflow_execution_history(
@@ -192,7 +200,7 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> HistoryTypeDef:
         """
-        [Client.get_workflow_execution_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.get_workflow_execution_history)
+        [Client.get_workflow_execution_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.get_workflow_execution_history)
         """
 
     def list_activity_types(
@@ -205,7 +213,7 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> ActivityTypeInfosTypeDef:
         """
-        [Client.list_activity_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.list_activity_types)
+        [Client.list_activity_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.list_activity_types)
         """
 
     def list_closed_workflow_executions(
@@ -222,7 +230,7 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> WorkflowExecutionInfosTypeDef:
         """
-        [Client.list_closed_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.list_closed_workflow_executions)
+        [Client.list_closed_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.list_closed_workflow_executions)
         """
 
     def list_domains(
@@ -233,7 +241,7 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> DomainInfosTypeDef:
         """
-        [Client.list_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.list_domains)
+        [Client.list_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.list_domains)
         """
 
     def list_open_workflow_executions(
@@ -248,12 +256,12 @@ class SWFClient:
         executionFilter: WorkflowExecutionFilterTypeDef = None,
     ) -> WorkflowExecutionInfosTypeDef:
         """
-        [Client.list_open_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.list_open_workflow_executions)
+        [Client.list_open_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.list_open_workflow_executions)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceOutputTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.list_tags_for_resource)
         """
 
     def list_workflow_types(
@@ -266,14 +274,14 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> WorkflowTypeInfosTypeDef:
         """
-        [Client.list_workflow_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.list_workflow_types)
+        [Client.list_workflow_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.list_workflow_types)
         """
 
     def poll_for_activity_task(
         self, domain: str, taskList: "TaskListTypeDef", identity: str = None
     ) -> ActivityTaskTypeDef:
         """
-        [Client.poll_for_activity_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.poll_for_activity_task)
+        [Client.poll_for_activity_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.poll_for_activity_task)
         """
 
     def poll_for_decision_task(
@@ -286,14 +294,14 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> DecisionTaskTypeDef:
         """
-        [Client.poll_for_decision_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.poll_for_decision_task)
+        [Client.poll_for_decision_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.poll_for_decision_task)
         """
 
     def record_activity_task_heartbeat(
         self, taskToken: str, details: str = None
     ) -> ActivityTaskStatusTypeDef:
         """
-        [Client.record_activity_task_heartbeat documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.record_activity_task_heartbeat)
+        [Client.record_activity_task_heartbeat documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.record_activity_task_heartbeat)
         """
 
     def register_activity_type(
@@ -310,7 +318,7 @@ class SWFClient:
         defaultTaskScheduleToCloseTimeout: str = None,
     ) -> None:
         """
-        [Client.register_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.register_activity_type)
+        [Client.register_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.register_activity_type)
         """
 
     def register_domain(
@@ -321,7 +329,7 @@ class SWFClient:
         tags: List["ResourceTagTypeDef"] = None,
     ) -> None:
         """
-        [Client.register_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.register_domain)
+        [Client.register_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.register_domain)
         """
 
     def register_workflow_type(
@@ -338,45 +346,45 @@ class SWFClient:
         defaultLambdaRole: str = None,
     ) -> None:
         """
-        [Client.register_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.register_workflow_type)
+        [Client.register_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.register_workflow_type)
         """
 
     def request_cancel_workflow_execution(
         self, domain: str, workflowId: str, runId: str = None
     ) -> None:
         """
-        [Client.request_cancel_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.request_cancel_workflow_execution)
+        [Client.request_cancel_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.request_cancel_workflow_execution)
         """
 
     def respond_activity_task_canceled(self, taskToken: str, details: str = None) -> None:
         """
-        [Client.respond_activity_task_canceled documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.respond_activity_task_canceled)
+        [Client.respond_activity_task_canceled documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.respond_activity_task_canceled)
         """
 
     def respond_activity_task_completed(self, taskToken: str, result: str = None) -> None:
         """
-        [Client.respond_activity_task_completed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.respond_activity_task_completed)
+        [Client.respond_activity_task_completed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.respond_activity_task_completed)
         """
 
     def respond_activity_task_failed(
         self, taskToken: str, reason: str = None, details: str = None
     ) -> None:
         """
-        [Client.respond_activity_task_failed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.respond_activity_task_failed)
+        [Client.respond_activity_task_failed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.respond_activity_task_failed)
         """
 
     def respond_decision_task_completed(
         self, taskToken: str, decisions: List[DecisionTypeDef] = None, executionContext: str = None
     ) -> None:
         """
-        [Client.respond_decision_task_completed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.respond_decision_task_completed)
+        [Client.respond_decision_task_completed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.respond_decision_task_completed)
         """
 
     def signal_workflow_execution(
         self, domain: str, workflowId: str, signalName: str, runId: str = None, input: str = None
     ) -> None:
         """
-        [Client.signal_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.signal_workflow_execution)
+        [Client.signal_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.signal_workflow_execution)
         """
 
     def start_workflow_execution(
@@ -394,12 +402,12 @@ class SWFClient:
         lambdaRole: str = None,
     ) -> RunTypeDef:
         """
-        [Client.start_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.start_workflow_execution)
+        [Client.start_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.start_workflow_execution)
         """
 
     def tag_resource(self, resourceArn: str, tags: List["ResourceTagTypeDef"]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.tag_resource)
         """
 
     def terminate_workflow_execution(
@@ -412,27 +420,27 @@ class SWFClient:
         childPolicy: Literal["TERMINATE", "REQUEST_CANCEL", "ABANDON"] = None,
     ) -> None:
         """
-        [Client.terminate_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.terminate_workflow_execution)
+        [Client.terminate_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.terminate_workflow_execution)
         """
 
     def undeprecate_activity_type(self, domain: str, activityType: "ActivityTypeTypeDef") -> None:
         """
-        [Client.undeprecate_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.undeprecate_activity_type)
+        [Client.undeprecate_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.undeprecate_activity_type)
         """
 
     def undeprecate_domain(self, name: str) -> None:
         """
-        [Client.undeprecate_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.undeprecate_domain)
+        [Client.undeprecate_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.undeprecate_domain)
         """
 
     def undeprecate_workflow_type(self, domain: str, workflowType: "WorkflowTypeTypeDef") -> None:
         """
-        [Client.undeprecate_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.undeprecate_workflow_type)
+        [Client.undeprecate_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.undeprecate_workflow_type)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Client.untag_resource)
         """
 
     @overload
@@ -440,7 +448,7 @@ class SWFClient:
         self, operation_name: Literal["get_workflow_execution_history"]
     ) -> GetWorkflowExecutionHistoryPaginator:
         """
-        [Paginator.GetWorkflowExecutionHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
+        [Paginator.GetWorkflowExecutionHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
         """
 
     @overload
@@ -448,7 +456,7 @@ class SWFClient:
         self, operation_name: Literal["list_activity_types"]
     ) -> ListActivityTypesPaginator:
         """
-        [Paginator.ListActivityTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
+        [Paginator.ListActivityTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
         """
 
     @overload
@@ -456,13 +464,13 @@ class SWFClient:
         self, operation_name: Literal["list_closed_workflow_executions"]
     ) -> ListClosedWorkflowExecutionsPaginator:
         """
-        [Paginator.ListClosedWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
+        [Paginator.ListClosedWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Paginator.ListDomains)
+        [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Paginator.ListDomains)
         """
 
     @overload
@@ -470,7 +478,7 @@ class SWFClient:
         self, operation_name: Literal["list_open_workflow_executions"]
     ) -> ListOpenWorkflowExecutionsPaginator:
         """
-        [Paginator.ListOpenWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
+        [Paginator.ListOpenWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
         """
 
     @overload
@@ -478,7 +486,7 @@ class SWFClient:
         self, operation_name: Literal["list_workflow_types"]
     ) -> ListWorkflowTypesPaginator:
         """
-        [Paginator.ListWorkflowTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
+        [Paginator.ListWorkflowTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
         """
 
     @overload
@@ -486,8 +494,5 @@ class SWFClient:
         self, operation_name: Literal["poll_for_decision_task"]
     ) -> PollForDecisionTaskPaginator:
         """
-        [Paginator.PollForDecisionTask documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.46/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
+        [Paginator.PollForDecisionTask documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.9/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
         """
-
-    def get_paginator(self, operation_name: str) -> Boto3Paginator:
-        pass
